# Changelog

## 1.0.0 (2025-06-16)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/Boomchainlab/agu-token/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* sync repo ([444675e](https://github.com/Boomchainlab/agu-token/commit/444675ef106b91d68404803b0d104c0e406dccd4))
* update SDK settings ([5e9e9e8](https://github.com/Boomchainlab/agu-token/commit/5e9e9e8e2fdc9c4e8d36c99055f6ee469eb56d5f))
* update SDK settings ([e258f51](https://github.com/Boomchainlab/agu-token/commit/e258f516ed254c5649d2e2e3bd4e8469412f2da3))
